package dataLoad;

import java.util.ArrayList;



import dataModel.*;
/**
* <h1>FullDataLoader</h1>
* Class responsible for reading the data from
* all input files.
*
* @version 1.0
* @since   2017-07-22
*/
public class FullDataLoader implements IFullDataLoader {

	public FullDataLoader(){
		empFile = "./input/employees.txt";
		empLoader = new EmployeeLoader();
		//empLoader = new OLDEmployeeLoader();
		dishFile = "./input/dishes.txt";
		dishLoader = new DishLoader();
		//dishLoader = new OldDishLoader();
		orderFile = "./input/orders.txt";
		orderLoader = new OrderLoader();
		//orderLoader = new OLDOrderLoader();
		
		
	}
	/**
 	 * Creates the mapping between the three different entities
 	 * (Employee, Dish, Order)
 	 * 
 	 * @param personnel: list holding information about employees
 	 * @param menu: list holding information about dishes
 	 * @param orders: list holding information about orders
 	 * 
 	 */
	public void assignOrders(ArrayList<Employee> personnel, ArrayList<Dish> menu, ArrayList<Order> orders){
		for (Order o: orders){
			String empName = o.getEmpName();
			String dishName = o.getDishName();
			for (Employee e: personnel){
				if (e.getName().equals(empName)){
					e.addOrder(o);
					o.setOrderEmp(e);
				}
			}
			for (Dish d: menu){
				if (d.getDishName().equals(dishName)){
					d.addOrder(o);
					o.setOrderDish(d);
				}
			}
		}
	}
	
	/**
 	 * Loads the three different types of files and stores
 	 * the data in the three different lists that receives 
 	 * as parameters.
 	 * 
 	 * @param personnel: empty list holding information about employees
 	 * @param menu: empty list holding information about dishes
 	 * @param orders: empty list holding information about orders
 	 * 
 	 * @return 0
 	 */
	@Override
	public int fullDataLoad(ArrayList<Employee> personnel, ArrayList<Dish> menu, ArrayList<Order> orders) {
		empLoader.load(empFile, "\t", true, 4, personnel);
		dishLoader.load(dishFile, "\t", true, 4, menu);
		orderLoader.load(orderFile, "\t", true, 5, orders);
		assignOrders(personnel, menu, orders);

		return 0;
	}

	
	//private IEmpLoader empLoader;
	//private IDishLoader dishLoader;
	//private IOrderLoader orderLoader;
	private String empFile;
	private String dishFile;
	private String orderFile;
	
	private DishLoader dishLoader;
	private EmployeeLoader empLoader;
	private OrderLoader orderLoader;
}
