package mainEngine;

import java.util.ArrayList;

import dataModel.*;
import javafx.collections.ObservableList;
import reportinEngines.IReportGenerator;
import reportinEngines.ReporterFactory;
import dataLoad.IFullDataLoader;
import dataLoad.FullDataLoaderFactory;
/**
* <h1>Chef</h1>
* Class responsible for (a) the load of the input files, (b) the 
* computation of the statistics and (c) the creation
* of reports
*
* @version 1.0
* @since   2017-07-22
*/
public class MainEngine implements IMainEngine{
	public MainEngine(){
		personnel = new ArrayList<Employee>();
		menu = new ArrayList<Dish>();
		orders = new ArrayList<Order>();
		dataLoaderFactory = new FullDataLoaderFactory();
		dataLoader = dataLoaderFactory.createFullDataLoader("FullDataLoader");
	}

	/**
 	 * Loads the data from the input files
 	 * 
 	 */
	public int loadAllData(){
		return dataLoader.fullDataLoad(personnel, menu, orders);		
	}
	
	/**
 	 * Computes the weekly statistics and the statistics
 	 * for each employee and prints the results
 	 * 
 	 */
	public void computeAllStats(){
		double totalGain = 0;
		double totalNumStars = 0;
		
		for(Dish d: menu){
			d.computeDishStats();
			totalGain += d.getGain();
			totalNumStars += d.getEvaluation();	
		}

		//MUST compute them BEFORE Emp Stats: Chef De cuisine depends on these numbers!
		WeeklyStats.setNumEmployees(personnel.size());
		WeeklyStats.setNumDishes(menu.size());
		WeeklyStats.setNumOrders(orders.size());
		WeeklyStats.setTotalGain(totalGain);
		WeeklyStats.setTotalAvgStars(totalNumStars/menu.size());
		
		for(Employee e: personnel){
			e.computeEmpStats();			
		}

		System.out.println("\n\nEmps: " + WeeklyStats.getNumEmployees() + "\tDishes: "+WeeklyStats.getNumDishes() +"\tOrders: " + WeeklyStats.getNumOrders() + "\tTotalGain: " + WeeklyStats.getTotalGain() + "\tAvgStars: " + WeeklyStats.getTotalAvgStars());
	}
	
	/**
 	 * Creates the different types of reports
 	 * 
 	 */
	public void createReports(String mode){
		ReporterFactory reporterFactory = new ReporterFactory();
		IReportGenerator reporter = reporterFactory.createReporter(mode);
		reporter.reportOnDishes(menu);
		reporter.reportOnEmps(personnel);
	}
	
	public void getEmployees(ObservableList<Employee> data){
		data.addAll(personnel);
	}
	public void getDishes(ObservableList<Dish> data){
		data.addAll(menu);
	}
		
	private ArrayList<Employee> personnel;
	private ArrayList<Dish> menu;
	private ArrayList<Order> orders;
	private IFullDataLoader dataLoader;
	private FullDataLoaderFactory dataLoaderFactory;

// Looser coupling: instead of using them as fields, I create an IReportGenerator ON-DEMAND within createReports()
//	private IReportGenerator reporter;
//	private ReporterFactory reporterFactory;
}
